@@ -10,11 +10,22 @@ import numpy as np
 from . import integrals
 from . import moderate_deviations
 from . import tnorms
-from . import networks
 from . import owas
 from . import overlaps
 
-supported_functions = ['mean', 'median', 'min', 'max', 'md', 'sugeno', 'shamacher', 'choquet', 'cfminmin', 'cf12', 'cf', 'owa1', 'owa2', 'owa3', 'geomean', 'sinoverlap', 'hmean', 'lucrezia']
+supported_functions = ['mean', 'median', 'min', 'max', 'sugeno', 'shamacher', 'choquet', 'cfminmin', 'cf12', 'cf', 'owa1', 'owa2', 'owa3', 'geomean', 'sinoverlap', 'hmean',
+                'hamacher', 'luka', 'drastic', 'nilpotent', 'probabilistic_sum', 'bounded_sum', 'drastic_tcnorm', 'nilpotent_maximum', 'einstein_sum']
+
+
+classic_aggs = ['mean', 'median', 'min', 'max']
+owa = ['owa1', 'owa2', 'owa3']
+fuzzy_integral = ['sugeno', 'choquet']
+choquet_family = ['choquet', 'cf', 'cf12', 'cfminmin']
+sugeno_family = ['sugeno', 'shamacher', 'fhamacher']
+tnorm = ['min', 'prod', 'hamacher', ' luka', 'drastic', 'nilpotent']
+tcnorm = ['probabilistic_sum', 'bounded_sum', 'drastic_tcnorm', 'nilpotent_maximum', 'einstein_sum']
+overlap = ['geomean', 'sinoverlap', 'hmean']
+
 
 def parse(agg_name, axis_f = 0, keepdims_f=True):
     agg_minuscula = agg_name.lower()
@@ -32,6 +43,9 @@ def parse(agg_name, axis_f = 0, keepdims_f=True):
         return lambda a, axis=axis_f, keepdims=keepdims_f: integrals.sugeno_fuzzy_integral(a, integrals.generate_cardinality_matrix(a.shape[axis], a.shape), axis=axis, keepdims=keepdims)
     elif agg_minuscula == 'shamacher':
         return lambda a, axis=axis_f, keepdims=keepdims_f: integrals.sugeno_fuzzy_integral_generalized(a, integrals.generate_cardinality_matrix(a.shape[axis], a.shape), axis=axis, keepdims=keepdims, f1 = tnorms.hamacher_tnorm, f2 = np.amax)
+    elif agg_minuscula == 'pre_hamacher':
+        my_pre = lambda x, y: x * np.abs(2*y - 1)
+        return lambda a, axis=axis_f, keepdims=keepdims_f: integrals.sugeno_fuzzy_integral_generalized(a, integrals.generate_cardinality_matrix(a.shape[axis], a.shape), axis=axis, keepdims=keepdims, f1 = my_pre, f2 = np.amax)    
     elif agg_minuscula == 'fhamacher':
         return lambda a, axis=axis_f, keepdims=keepdims_f: integrals.sugeno_fuzzy_integral_generalized(a, integrals.generate_cardinality_matrix(a.shape[axis], a.shape), axis=axis, keepdims=keepdims, f1 = tnorms.prod, f2 = np.sum)
     elif agg_minuscula == 'choquet':
@@ -54,8 +68,27 @@ def parse(agg_name, axis_f = 0, keepdims_f=True):
         return lambda a, axis=axis_f, keepdims=keepdims_f: overlaps.sin_overlap(a, axis=axis, keepdims=keepdims)
     elif agg_minuscula == 'hmean':
         return lambda a, axis=axis_f, keepdims=keepdims_f: overlaps.harmonic_mean(a, axis=axis, keepdims=keepdims)
-    elif agg_minuscula == 'lucrezia':
-        return lambda a, axis=axis_f, keepdims=keepdims_f: networks.lucrezia_simple_decisor(a, axis=axis, keepdims=keepdims, tnorm=np.minimum, agg_function=np.mean)
+    elif agg_minuscula == 'hamacher':
+        return lambda a, axis=axis_f, keepdims=keepdims_f: tnorms.hamacher_tnorm(a, axis=axis, keepdims=keepdims)
+    elif agg_minuscula == 'luka':
+        return lambda a, axis=axis_f, keepdims=keepdims_f: tnorms.lukasiewicz_tnorm(a, axis=axis, keepdims=keepdims)
+    elif agg_minuscula == 'drastic':
+        return lambda a, axis=axis_f, keepdims=keepdims_f: tnorms.drastic_tnorm(a, axis=axis, keepdims=keepdims)           
+    elif agg_minuscula == 'nilpotent':
+        return lambda a, axis=axis_f, keepdims=keepdims_f: tnorms.nilpotent_tnorm(a, axis=axis, keepdims=keepdims)
+    elif agg_minuscula == 'probabilistic_sum':
+        return lambda a, axis=axis_f, keepdims=keepdims_f: tnorms.probabilistc_sum(a, axis=axis, keepdims=keepdims)    
+    elif agg_minuscula == 'bounded_sum':
+        return lambda a, axis=axis_f, keepdims=keepdims_f: tnorms.bounded_sum(a, axis=axis, keepdims=keepdims)
+    elif agg_minuscula == 'drastic_tcnorm':
+        return lambda a, axis=axis_f, keepdims=keepdims_f: tnorms.drastic_tcnorm(a, axis=axis, keepdims=keepdims)
+    elif agg_minuscula == 'nilpotent_maximum':
+        return lambda a, axis=axis_f, keepdims=keepdims_f: tnorms.nilpotent_maximum(a, axis=axis, keepdims=keepdims)
+    elif agg_minuscula == 'einstein_sum':
+        return lambda a, axis=axis_f, keepdims=keepdims_f: tnorms.einstein_sum(a, axis=axis, keepdims=keepdims)
+    elif agg_minuscula == 'prod':
+        return lambda a, axis=axis_f, keepdims=keepdims_f: tnorms.prod(a, axis=axis, keepdims=keepdims)
+    
     elif agg_minuscula == 'mode':
         from scipy.stats import mode
         if keepdims_f:
